/*
 *  Copyright (c) 2002, Tayeb Lemlouma
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer. 
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution. 
 *  Neither the name of the Opera Project (INRIA Rhne Alpes) nor the names
 *  of its contributors may be used to endorse or promote products derived
 *  from this software without specific prior written permission.
 *   
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fr.inrialpes.opera.upsprofiles;

import java.io.*;
/**
 * This class allows adding a component to the global CC/PP profile.
 *
 *@author     Tayeb LEMLOUMA (Tayeb.Lemlouma@inrialpes.fr)
 *@created    25 April 2002
 */

public class AddComponent{
    /**
    * Adds a CC/PP component to the global profile file. 
    *
    *@param	profileTypeName	The type of the profile. 
    *@param	ccppComponentName	The name of the CC/PP component.
    *@param	C	The util information of the component
    *@param	out	point to the file of the profile
    */    
    public AddComponent(String profileTypeName,String ccppComponentName, String C, OutputStreamWriter out){
    try{

      out.write("<ccpp:component>\r\n");
      out.write("<rdf:Description rdf:ID=\""+ccppComponentName+"\">\r\n");
      out.write("<rdf:type rdf:resource=\"http://www.inrialpes.fr/opera/people/Tayeb.Lemlouma/NegotiationSchema/"+profileTypeName+"-03012002#"+ccppComponentName+"\"/>\r\n");
      new SetComponentContent(ccppComponentName, C, out);
      out.write("</rdf:Description>\r\n");
      out.write("</ccpp:component>\r\n");
    }catch (IOException e){
    	System.err.println(e);
    }
    	
    }//end AddComponent
    /**
    * Adds a CC/PP component to the global file of the resource client profile. 
    *
    *@param	profileTypeName	The type of the profile. 
    *@param	ccppComponentName	The name of the CC/PP component.
    *@param	C1	The first util information of the component
    *@param	C2	The second util information of the component
    *@param	out	point to the file of the profile
    */    
    public AddComponent(String profileTypeName,String ccppComponentName, String C1, String C2, OutputStreamWriter out){
    try{

      out.write("<ccpp:component>\r\n");
      out.write("<rdf:Description rdf:ID=\""+ccppComponentName+"\">\r\n");
      out.write("<rdf:type rdf:resource=\"http://www.inrialpes.fr/opera/people/Tayeb.Lemlouma/NegotiationSchema/"+profileTypeName+"-03012002#"+ccppComponentName+"\"/>\r\n");
      new SetComponentContent(ccppComponentName, C1, C2, out);
      out.write("</rdf:Description>\r\n");
      out.write("</ccpp:component>\r\n");
    }catch (IOException e){
    	System.err.println(e);
    }
    	
    }//end AddComponent

}//end class