/*
 *  Copyright (c) 2002, Tayeb Lemlouma
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer. 
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution. 
 *  Neither the name of the Opera Project (INRIA Rhne Alpes) nor the names
 *  of its contributors may be used to endorse or promote products derived
 *  from this software without specific prior written permission.
 *   
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fr.inrialpes.opera.upsprofiles;

import java.io.*; 

/**
 * This class sets the content of a component of the global CC/PP profile.
 *
 *@author     Tayeb LEMLOUMA (Tayeb.Lemlouma@inrialpes.fr)
 *@created    25 April 2002
 */
public class SetComponentContent{
    /**
    * Sets the content of a CC/PP component. Component can be: HardwarePlatform, SoftwarePlatform,  
    * BrowserUA, DocumentInstanceDescription, MultimediaContent,AdaptableResourcesDescription,
    * MediaResourceDescription, AdaptationMethodResourceDescription, AdaptationMethodResourceDescription or
    * AdaptationMethodDescription.  
    *@param	ccppComponentName	The name of the CC/PP component.
    *@param	Content	The util information of the component
    *@param	out	point to the file of the profile
    */        
    public SetComponentContent(String ccppComponentName, String Content, OutputStreamWriter out){
    try{

	if(ccppComponentName.equals("HardwarePlatform")){
		new SetCCPP_H_S_PlatformComponent(Content, out);
	}//end if
	if(ccppComponentName.equals("SoftwarePlatform")){
		new SetCCPP_H_S_PlatformComponent(Content, out);
	}//end if
	if(ccppComponentName.equals("BrowserUA")){
		new SetCCPPBowserUAComponent(Content, out);
	}//end if
	
	if(ccppComponentName.equals("DocumentInstanceDescription")){
		new SetCCPP_H_S_PlatformComponent(Content, out);
	}//end if
	
	if(ccppComponentName.equals("MultimediaContent")){
		new SetResourcesContainer(Content, out);
	}//end if
	if(ccppComponentName.equals("AdaptableResourcesDescription")){
		new SetResourcesContainer(Content, out);
	}//end if
	if(ccppComponentName.equals("MediaResourceDescription")){
		new SetCCPP_H_S_PlatformComponent(Content, out);
	}//end if
	if(ccppComponentName.equals("AdaptationMethodResourceDescription")){
		new SetCCPP_H_S_PlatformComponent(Content, out);
	}//end if
	if(ccppComponentName.equals("AdaptationMethodDescription")){
		new SetResourcesContainer(Content, out);
	}//end if
	
    }catch(Exception e){
     System.err.println("Error during the creation of the CC/PP content, make sure that the content parameters (Ci) is correct:\n"+e);
    }//end try
    
    
    }//end SetComponentContent
    /**
    * Sets the content of the CC/PP component: ContentRequirement.
    *@param	ccppComponentName	The name of the CC/PP component.
    *@param	Content1	The 1st util information of the component
    *@param	Content2	The 2nd util information of the component
    *@param	out	point to the file of the profile
    */        
    public SetComponentContent(String ccppComponentName, String Content1, String Content2, OutputStreamWriter out){
    try{
	if(ccppComponentName.equals("ContentRequirement")){
		new SetContentRequirement(Content1, Content2, out);
	}

    }catch(Exception e){
     System.err.println("Error during the creation of the CC/PP content, make sure that the content parameters (Ci) is correct:\n"+e);
    }//end try
    }//end SetComponentContent

}//end class