/*
 *  Copyright (c) 2002, Tayeb Lemlouma
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer. 
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution. 
 *  Neither the name of the Opera Project (INRIA Rhne Alpes) nor the names
 *  of its contributors may be used to endorse or promote products derived
 *  from this software without specific prior written permission.
 *   
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fr.inrialpes.opera.upsprofiles;

import java.io.*;
/**
 * This class allows to set the content of the 'ContentRequirement' component of the profile named 
 * 'ResourceClientProfile' defined in the UPS Schema.
 *
 *@author     Tayeb LEMLOUMA (Tayeb.Lemlouma@inrialpes.fr)
 *@created    25 April 2002
 */
public class SetContentRequirement{
    /**
    * Sets the content of the 'ContentRequirement' component of the profile named 
    * 'ResourceClientProfile' defined in the UPS Schema.
    *@param	Content1	The 1st util information of the component
    *@param	Content2	The 2nd util information of the component
    *@param	out	point to the file of the profile
    */ 

	public SetContentRequirement(String Content1, String Content2, OutputStreamWriter out){
		try{
			String contN="",parseType="", strN="", strV; char c; int i; 
			
			i=0;
			//process the 1st part of the content (general constraints)
			//retrieve the content container name
			while ((c=Content1.charAt(i))!='|') {contN += c;i++;}
			out.write("<neg:"+contN+">\r\n");

			if(contN.equals("Content")) out.write("<rdf:Bag>\r\n");
			i++;			
			//retrieve /R
			while ((c=Content1.charAt(i))!='|') {parseType += c;i++;}

			i++;
			if(parseType.equals("/R")){
				out.write("	<rdf:li rdf:parseType=\"Resource\">\r\n");
				parseType="";
			}
			//retrieving Resources Bags inside general constraints
			while(i<Content1.length()){
				//retrive the list tag-name/tag-value of the bag
				 while(i< Content1.length()){
					 strN="";
					 while ((c=Content1.charAt(i))!='|') {strN += c;i++;}
					 //retrieve the tag value
					 i++;
					 if(strN.equals("/R")) break;
					 strV="";
					 while ((i< Content1.length()) && ((c=Content1.charAt(i))!='|')) {strV += c;i++;}
					 out.write("	 <neg:"+strN+">"+strV+"</neg:"+strN+">\r\n");
					 i++;
				 }//end while
				
				//The end of a service or a resource bag
				if(strN.equals("/R")){
					out.write("	</rdf:li>\r\n");
					out.write("	<rdf:li rdf:parseType=\"Resource\">\r\n");
					parseType=strN;
				}//end if
			
			}//end while i
			//close the last rdf Resource
			out.write("	</rdf:li>\r\n");


			//process the second part of the content detailed constraints
			i=0;
			//retrieve /R
			while ((c=Content2.charAt(i))!='|') {parseType += c;i++;}
			i++;
			if(parseType.equals("/R")){
				out.write("	<rdf:li rdf:parseType=\"Resource\">\r\n");
				parseType="";
			}
			int j=i;
			String compN="";
			for(i=j; i< Content2.length(); i++){
			//retrive direct info
			 while(i< Content2.length()){
				 strN="";
				 while ((c=Content2.charAt(i))!='|') {strN += c;i++;}
				 //retrieve the tag value
				 i++;
				 if(strN.equals("/OSR") || strN.equals("/PSR") || strN.equals("/NSR")) break;
				 strV="";
				 while ((i< Content2.length()) && ((c=Content2.charAt(i))!='|')) {strV += c;i++;}
				 
				 out.write("	 <neg:"+strN+">"+strV+"</neg:"+strN+">\r\n");
				 i++;
			 }//end while
			compN=strN;
			//retrieving OSR, PSR or NSR Components
			while(i< Content2.length()){
		
				if(compN.equals("/OSR")){
					
					out.write("	 <neg:OnlySupportedResources>\r\n");
				}
				if(compN.equals("/PSR")){
					
					out.write("	 <neg:PrederredSupportedResources>\r\n");
				}
				if(compN.equals("/NSR")){
					
					out.write("	 <neg:NonSupportedResources>\r\n");
				}
				
				out.write("	 <rdf:Bag>\r\n");
		
				//retrieve the rdf parseType
				parseType="";
				while ((c=Content2.charAt(i))!='|') {parseType += c;i++;}
				i++;
				
				//retrieving elments (/E) of Resources Bags inside OSR, PSR or NSR
				while(i< Content2.length()){
					if(parseType.equals("/E")){
					out.write("	 <rdf:li rdf:parseType=\"Resource\">\r\n");
					}
					//retrive the list tag-name/tag-value of the bag
					 while(i< Content2.length()){
						 strN="";
						 while ((c=Content2.charAt(i))!='|') {strN += c;i++;}
						 //retrieve the tag value
						 i++;
						 if(strN.equals("/E") || strN.equals("/R") || strN.equals("/OSR") || strN.equals("/PSR") || strN.equals("/NSR")) break;
						 strV="";
						 while ((i< Content2.length()) && ((c=Content2.charAt(i))!='|')) {strV += c;i++;}
						 
						 out.write("	 	<neg:"+strN+">"+strV+"</neg:"+strN+">\r\n");
						 i++;
					 }//end while
					
					//The end of a service or a resource bag
					if(strN.equals("/E")){
						out.write("	 </rdf:li>\r\n");
						parseType=strN;
					}//end if
					
					if(strN.equals("/R") || strN.equals("/OSR") || strN.equals("/PSR") || strN.equals("/NSR")) break; 
				}//end while of Resources or Services Bags
				
				//The end of a constraint resource
				//The end of OSR, PSR or NSR component
				if(strN.equals("/R") || strN.equals("/OSR") || strN.equals("/PSR") || strN.equals("/NSR")){
					
					out.write("	 </rdf:li>\r\n");
					out.write("	 </rdf:Bag>\r\n");
					if(compN.equals("/OSR")){
						out.write("	 </neg:OnlySupportedResources>\r\n");
					}
					if(compN.equals("/PSR")){
						out.write("	 </neg:PrederredSupportedResources>\r\n");
					}
					if(compN.equals("/NSR")){
						out.write("	 </neg:NonSupportedResources>\r\n");
					}
					compN=strN;
				}//end if strN.equals /OSR
				if(strN.equals("/R")){
					out.write("	 </rdf:li>\r\n"); 
					out.write("	<rdf:li rdf:parseType=\"Resource\">\r\n");break;	
				}//end if strN.equals /R

			  }//end while of Components 
	

			}//end for i
			//Close the last Resource Bag and O/N/P-SR component
			out.write("	 </rdf:li>\r\n");
			out.write("	 </rdf:Bag>\r\n");
			if(compN.equals("/OSR")){
				out.write("	 </neg:OnlySupportedResources>\r\n");
			}
			if(compN.equals("/PSR")){
				out.write("	 </neg:PrederredSupportedResources>\r\n");
			}
			if(compN.equals("/NSR")){
				
				out.write("	 </neg:NonSupportedResources>\r\n");
			}
			out.write("	 </rdf:li>\r\n");
			if(contN.equals("Content")) out.write("</rdf:Bag>\r\n");	
			out.write("</neg:"+contN+">\r\n");

		}catch(Exception e){
		System.err.println("Error during seting the resources container content: "+e);
		}//end try
		



	}//end SetContentRequirement
}//end public class
