/*
 *  Copyright (c) 2002, Tayeb Lemlouma
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer. 
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution. 
 *  Neither the name of the Opera Project (INRIA Rhne Alpes) nor the names
 *  of its contributors may be used to endorse or promote products derived
 *  from this software without specific prior written permission.
 *   
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fr.inrialpes.opera.upsprofiles;

import java.io.*;

/**
 * This class sets the content of some components of the global proper to the content negotiation problem.
 *
 *@author     Tayeb LEMLOUMA (Tayeb.Lemlouma@inrialpes.fr)
 *@created    25 April 2002
 */
public class SetResourcesContainer{

    	/**
    	* Sets the content of components proper to the content negotiation problem (see the UPS schema). 
    	* Concerned components are: MultimediaContent, AdaptableResourcesDescription and AdaptationMethodDescription
    	*@param	Content	The util information of the component
    	*@param	out	point to the file of the profile
    	*/   
	public SetResourcesContainer(String Content, OutputStreamWriter out){
		try{
			String contN="",parseType="", strN="", strV; char c; int i; 
			
			i=0;
			//retrieve the container name
			while ((c=Content.charAt(i))!='|') {contN += c;i++;}

			out.write("<neg:"+contN+">\r\n");
			//System.out.println("contN: "+contN);
			
			if(contN.equals("Content")) out.write("<rdf:Bag>\r\n");
			if(contN.equals("AdaptableResources")) out.write("<rdf:Alt>\r\n");
			if(contN.equals("SubAdaptationMethods")) out.write("<rdf:Bag>\r\n");
			
			i++;			
			//retrieve /R
			while ((c=Content.charAt(i))!='|') {parseType += c;i++;}
			//System.out.println("parseType: "+parseType);
			i++;
			if(parseType.equals("/R")){
				out.write("	<rdf:li rdf:parseType=\"Resource\">\r\n");
				parseType="";
			}
			//retrieving Resources Bags inside OSR, PSR or NSR
			while(i<Content.length()){
				//retrive the list tag-name/tag-value of the bag
				 while(i< Content.length()){
					 strN="";
					 while ((c=Content.charAt(i))!='|') {strN += c;i++;}
					 //retrieve the tag value
					 i++;
					 if(strN.equals("/R")) break;
					 strV="";
					 while ((i< Content.length()) && ((c=Content.charAt(i))!='|')) {strV += c;i++;}
					 
					 //System.out.println("str: "+strN+" val: "+strV);
					 out.write("	 <neg:"+strN+">"+strV+"</neg:"+strN+">\r\n");
					 i++;
				 }//end while
				
				//The end of a service or a resource bag
				if(strN.equals("/R")){
					out.write("	</rdf:li>\r\n");
					out.write("	<rdf:li rdf:parseType=\"Resource\">\r\n");
					parseType=strN;
				}//end if
			
			}//end while i
			//close the last rdf Resource
			out.write("	</rdf:li>\r\n");
			if(contN.equals("Content")) out.write("</rdf:Bag>\r\n");
			if(contN.equals("AdaptableResources")) out.write("</rdf:Alt>\r\n");
			if(contN.equals("SubAdaptationMethods")) out.write("</rdf:Bag>\r\n");
			out.write("</neg:"+contN+">\r\n");

		}catch(Exception e){
		System.err.println("Error during seting the resources container content: "+e);
		}//end try
		
	}//end SetResourcesCointainer
}//end class

