/*
 *  Copyright (c) 2002, Tayeb Lemlouma
 *  All rights reserved.
 *  
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer. 
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution. 
 *  Neither the name of the Opera Project (INRIA Rhne Alpes) nor the names
 *  of its contributors may be used to endorse or promote products derived
 *  from this software without specific prior written permission.
 *   
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *  TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package fr.inrialpes.opera.upsprofiles;

import java.io.*;
import fr.inrialpes.opera.upsprofiles.SetCCPP_H_S_PlatformComponent;
/**
 * This class allows to create different kinds of CC/PP profiles
 *
 *@author     Tayeb LEMLOUMA (Tayeb.Lemlouma@inrialpes.fr)
 *@created    25 April 2002
 */

public class UPSProfilesCreator {

OutputStreamWriter out; 
    
    /**
    * Create a valid CC/PP profile file, with three CC/PP components: Hardware Platform, Software Platform and Browser User Agent. 
    * The created profile follows the UPS schema, and belongs to the profile type passed as argument.  
    *
    *@param	fileName	The file name of the created profile. 
    *@param	profileTypeName		The type of the profile. Possible values: ClientProfile, DocumentInstanceProfile.
    *@param	C1	1st Util information (semantic depends to the kind of the profile)
    *@param	C2	2nd Util information (semantic depends to the kind of the profile)    
    *@param	C3	3rd Util information (semantic depends to the kind of the profile)
    */

    public UPSProfilesCreator(String fileName, String profileTypeName, String C1, String C2, String C3){
		
    try {
      FileOutputStream fout = new FileOutputStream(fileName);
      out = new OutputStreamWriter(fout);
      //OutputStreamWriter out = new OutputStreamWriter(fout, "ISO-8859-1"/*this is the encoding, example "8859_1"*/);
      
      //---- Profile Head Declaration
      out.write("<?xml version=\"1.0\"?>\r\n");
      out.write("<rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\r\n");
      out.write("xmlns:ccpp=\"http://www.w3.org/2000/07/04-ccpp#\"\r\n");
      out.write("xmlns:neg=\"http://www.inrialpes.fr/opera/people/Tayeb.Lemlouma/NegotiationSchema/"+profileTypeName+"Schema-03012002#\">\r\n");
      //---- Profile Name or ID
      out.write("<rdf:Description rdf:ID=\""+profileTypeName+"\">\r\n");
      //---- Profile Required Components
      if(profileTypeName.equals("DocumentInstanceProfile")){
	      new AddComponent(profileTypeName,"DocumentInstanceDescription", C1, out);
	      new AddComponent(profileTypeName,"MultimediaContent", C2, out);
	      new AddComponent(profileTypeName,"AdaptableResourcesDescription", C3, out);
      }//end if
      if(profileTypeName.equals("ResourceProfile")){
              new AddComponent(profileTypeName,"MediaResourceDescription", C1, out);
              new AddComponent(profileTypeName,"AdaptableResourcesDescription", C2, out);
      }//end if
      if(profileTypeName.equals("AdaptationMethodProfile")){
              new AddComponent(profileTypeName,"AdaptationMethodResourceDescription", C1, out);
              new AddComponent(profileTypeName,"AdaptationMethodDescription", C2, out);
      }//end if
      if(profileTypeName.equals("ClientProfile")){
      	      new AddComponent(profileTypeName,"HardwarePlatform", C1, out);
      	      new AddComponent(profileTypeName,"SoftwarePlatform", C2, out);
      	      new AddComponent(profileTypeName,"BrowserUA", C3, out);
      }//end if
      if(profileTypeName.equals("ResourceClientProfile")){
      	      new AddComponent(profileTypeName,"ContentRequirement", C1, C2, out);
      }//end if	
      out.write("</rdf:Description>\r\n");
      out.write("</rdf:RDF>");

      out.close();
    }
    catch (IOException e) {
      System.err.println(e);
    }
		
    }//end UPSProfilesCreator
    /**
    * Create a valid CC/PP profile file, with two CC/PP components. The created profile follows the UPS schema,
    * and belongs to the profile type passed as argument.  
    *
    *@param	fileName	The file name of the created profile 
    *@param	profileTypeName		The type of the profile. Possible values: ResourceProfile, AdaptationMethodProfile and ResourceClientProfile.
    *@param	C1	1st Util information (semantic depends to the kind of the profile)
    *@param	C2	2nd Util information (semantic depends to the kind of the profile)    
    */

    public UPSProfilesCreator(String fileName, String profileTypeName, String C1, String C2){
		
    try {
      FileOutputStream fout = new FileOutputStream(fileName);
      out = new OutputStreamWriter(fout);
      //OutputStreamWriter out = new OutputStreamWriter(fout, "ISO-8859-1"/*this is the encoding, example "8859_1"*/);
      
      //---- Profile Head Declaration
      out.write("<?xml version=\"1.0\"?>\r\n");
      out.write("<rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\r\n");
      out.write("xmlns:ccpp=\"http://www.w3.org/2000/07/04-ccpp#\"\r\n");
      out.write("xmlns:neg=\"http://www.inrialpes.fr/opera/people/Tayeb.Lemlouma/NegotiationSchema/"+profileTypeName+"Schema-03012002#\">\r\n");
      //---- Profile Name or ID
      out.write("<rdf:Description rdf:ID=\""+profileTypeName+"\">\r\n");
      //---- Profile Required Components
      if(profileTypeName.equals("ResourceProfile")){
              new AddComponent(profileTypeName,"MediaResourceDescription", C1, out);
              new AddComponent(profileTypeName,"AdaptableResourcesDescription", C2, out);
      }//end if
      if(profileTypeName.equals("AdaptationMethodProfile")){
              new AddComponent(profileTypeName,"AdaptationMethodResourceDescription", C1, out);
              new AddComponent(profileTypeName,"AdaptationMethodDescription", C2, out);
      }//end if
      if(profileTypeName.equals("ResourceClientProfile")){
      	      new AddComponent(profileTypeName,"ContentRequirement", C1, C2, out);
      }//end if	
      out.write("</rdf:Description>\r\n");
      out.write("</rdf:RDF>");

      out.close();
    }
    catch (IOException e) {
      System.err.println(e);
    }
		
    }//end UPSProfilesCreator

	/**
	* This main class is written for testing the UPSProfiles package. 
	* It creates five profiles in the directory given as argument, otherwise in the current directory.
	*/	
	public static void main(String[] args) {
		String root="";
		if(args.length==1) root=args[0];
		String CCPPProfileName, CCPPProfileType, Co1, Co2, Co3;
		/*
		Client Profile
		Syntax: The parameter Coi represents the component number i
		Current Format (UPS version 03-01-2002):
		Hardware Platform(Co1 format): Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|
		Software Platform(Co2 format): Tag-Name|Tag-Value|...|Tag-Name|Tag-Value
		Browser UA(Co3 format): Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|/OSR|/R|Tag-Name|Tag-Value|...|/R|Tag-Name|Tag-Value|...
		            /PSR|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|...
		            /NSR|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value
		OSR: Only Supported Resources component
		PSR: Preferred Supported Resources component
		NSR: Non Supported Resources component
		R: parseType=Resource
		Browser UA(Co3 format): First we have the list of direct BrowserUA tag-name and value, followed by
			    the list of OSR, PSR or NSR components. 
			    In each component, after /R, we have the list of (tag,values) grouping in a single bag
			    		
		*/
		CCPPProfileName=root+"XMLExample1.xml";
		CCPPProfileType="ClientProfile";
		Co1="DeviceType|Pocket PC|DeviceName|iPAQ 3600|DeviceConstructor|COMPAQ Computer Corp.|screen|240x320Pixels|screenColor|yes|RAMSize|32Mo|ROMSize|16Mo|";
		Co2="PlatformName|Windows CE|PlatformVersion|3.0";
		Co3="UsedPlayerName|Windows CE Pocket IE|UsedPlayerVersion|3.0 PPC|/OSR|/R|type|HTML|version|3.2|format|html|format|htm|type|Frame|type|JScript|type|ActiveX|functionality|User authentication|kind|Basic|functionality|Encryption|format|64bit|format|128bit|/NSR|/R|type|DHTML|type|CSS|type|VBScript|type|Java VM|type|VRML|type|GIF|type|downloadable fonts|/PSR|/R|type|language|format|french|priorityLevel|1";
		new UPSProfilesCreator(CCPPProfileName,CCPPProfileType,Co1,Co2,Co3);
		System.out.println("\nProfile \""+CCPPProfileName+"\" Created.");
		
		/*
		Document Instance Profile
		Syntax: The parameter Coi represents the component number i
		Current Format (UPS version 03-01-2002):
		DocumentInstanceDescription (Co1 format): Tag-Name|Tag-Value|...|Tag-Name|Tag-Value| 
		MultimediaContent (Co2 format): Content|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|
		AdaptableResourcesDescription (Co3 format): AdaptableResources|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|
		*/
		
		CCPPProfileName=root+"XMLExample2.xml";
		CCPPProfileType="DocumentInstanceProfile";
		Co1="InstanceType|HTML|InstanceFormat|html|InstanceVersion|4.01|InstanceDoctype|http://www.w3.org/TR/html4/loose.dtd|InstanceName|EXAMPLE.html|InstanceLanguage|english|InstanceSize|910Bytes|InstanceLocation|Smil/T/NEGOTIATION/WAP/|InstanceServer|http://opera.inrialpes.fr/";
		Co2="Content|/R|type|image|format|jpg|profile|profiles/background-jpg-profile.xml|profile|profiles/phone-jpg-profile.xml|profile|profiles/thank_you-jpg-profile.xml|type|image|format|gif|profile|profiles/realplayer-gif-profile.xml|/R|type|audio|format|wav|profile|profiles/WapTechnology-wav-profile.xml";
		Co3="AdaptableResources|/R|type|textResume|format|xml|profile|profiles/EXAMPLE-xml-profile.xml|AdaptabilityValue|0.2";
		new UPSProfilesCreator(CCPPProfileName,CCPPProfileType,Co1,Co2,Co3);
		System.out.println("\nProfile \""+CCPPProfileName+"\" Created.");
		
		/*
		Resource Profile
		Syntax: The parameter Coi represents the component number i
		Current Format (UPS version 03-01-2002):
		MediaResourceDescription (Co1 format): Tag-Name|Tag-Value|...|Tag-Name|Tag-Value| 
		MultimediaContent (Co2 format): AdaptableResources|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|
		*/

		CCPPProfileName=root+"XMLExample3.xml";
		CCPPProfileType="ResourceProfile";
		Co1="name|background.jpg|format|jpg|size|25824Bytes|location|Smil/T/NEGOTIATION/WAP/images/|server|http://opera.inrialpes.fr/|dimension|800x600Pixels|resolution|300x300Pixels|colorBit|24|colorRepresentation|true RGB";
		Co2="AdaptableResources|/R|type|image|format|gif|profile|profiles/background02-gif-profile.xml|adaptabilityValue|3|/R|type|method|outputFormat|gif|outputFormat|wbmp|profile|profiles/jpgtransformer-class-profile.xml";
		new UPSProfilesCreator(CCPPProfileName,CCPPProfileType,Co1,Co2);
		System.out.println("\nProfile \""+CCPPProfileName+"\" Created.");
		
		/*
		Adaptation Method Profile
		Syntax: The parameter Coi represents the component number i
		Current Format (UPS version 03-01-2002):
		AdaptationMethodResourceDescription (Co1 format): Tag-Name|Tag-Value|...|Tag-Name|Tag-Value 
		AdaptationMethodDescription (Co2 format): SubAdaptationMethods|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value
		Here each resource cointain input requirement and output description: such as inputType XML, outputType: LATEX
		*/

		CCPPProfileName=root+"XMLExample4.xml";
		CCPPProfileType="AdaptationMethodProfile";
		Co1="type|XSLT style sheet|format|xsl|name|XML2LaTeX.xsl|size|19568Bytes";
		Co2="SubAdaptationMethods|/R|inputType|XML|inputFormat|xml|inputResourceDoctype|http://www.inrialpes.fr/opera/people/Tayeb.Lemlouma/MULTIMEDIA/XSLT/LaTeXDTD.dtd|outputType|LATEX|outputFormat|tex";
		new UPSProfilesCreator(CCPPProfileName,CCPPProfileType,Co1,Co2);
		System.out.println("\nProfile \""+CCPPProfileName+"\" Created.");
		/*
		Client Resource Profile
		Syntax: The parameter Coi represents the component number i
		Current Format (UPS version 03-01-2002):
		Content Requirement Co1 && Co2:
		Co1 format: Content|/R|Tag-Name|Tag-Value|...|Tag-Name|Tag-Value| 
		Co2 format: /R|Tag-Name|Tag-Value|..|/X|/E|Tag-Name|Tag-Value|...|/E|Tag-Name|Tag-Value|/X|/E|Tag-Name|Tag-Value|...|/E|Tag-Name|Tag-Value|..
			    ../R|Tag-Name|Tag-Value|..|/X|/E|Tag-Name|Tag-Value|...|/E|Tag-Name|Tag-Value|/X|/E|Tag-Name|Tag-Value|...|/E|Tag-Name|Tag-Value|..
		
		Couples of (Tag-Name,Tag-Value) are the direct values of the <neg:Content> RDF Bag
		X can be OSR, PSR or NSR
		OSR: represents the Only Supported Resources component
		PSR: represents the Preferred Supported Resources component
		NSR: represents the Non Supported Resources component
		Each component (OSR, PSR or NSR) is an RDF bag and contains a set of elemnts of the type: E.
		E: is a <rdf:li rdf:parseType="Resource"> element that contains a set of couples (Tag-Name,Tag-Value)
		
		*/

		CCPPProfileName=root+"XMLExample5.xml";
		CCPPProfileType="ResourceClientProfile";
		Co1="Content|/R|type|WML element|signification|WML card|name|card|maxSize|3000Bytes|";
		Co2="/R|signification|WML text|/OSR|/E|type|element|signification|text style|requirement|small|requirement|bold|requirement|emphasis|requirement|strong|/E|type|WML attribute|signification|text alignment|name|p/align|requirement|left|requirement|center|requirement|right|/R|signification|another-resource|/NSR|/E|type|type-of-the-NSR|signification|sign..|/E|type|other type|signification|other signification";
		new UPSProfilesCreator(CCPPProfileName,CCPPProfileType,Co1,Co2);
		System.out.println("\nProfile \""+CCPPProfileName+"\" Created.");


	}//end of main

}//end of class

